<?php
namespace Geral\Repositories;

class Trabnececomp extends \Doctrine\ORM\EntityRepository
{
    /**
     * Retorna os dados do grid Por data
     *
     * @param String $nrorg Organização
     * @param String $nrnececomp Número da necessidade de compras
     * @param String $cdfilnececmp Filial
     *
     * @return array
     * @throws \Exception
     */
    public static function getListaPorData($nrorg, $nrnececomp, $cdfilnececmp)
    {
        $sql = "SELECT DISTINCT(DTENTRNECCMP)
            FROM TRABNECECOMP
            WHERE NRORG = :P_NRORG
            AND NRNECECOMP = :P_NRNECECOMP
            AND CDFILNECECMP = :P_CDFILNECECMP
            AND IDMARCNECCMP = 'S'
            ORDER BY DTENTRNECCMP";

        $paramsWhere = array(
            'P_NRORG'       => $nrorg,
            'P_NRNECECOMP'   => $nrnececomp,
            'P_CDFILNECECMP' => $cdfilnececmp,
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            return $conn->fetchAll($sql, $paramsWhere);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Retorna os dados do grid Lista da aba Por Produto
     * @param $nrorg
     * @param $nrnececomp
     * @param $cdfilnececmp
     * @param $cdprodneccmp
     * @param $dtentrneccmp
     * @param $dtfinal
     * @return array
     * @throws \Exception
     */
    public static function getListaPorProduto(
        $nrorg, $nrnececomp, $cdfilnececmp, $cdprodneccmp, $dtentrneccmp,
        $dtfinal
    ) {
        $sql = "SELECT DISTINCT(DTENTRNECCMP)
            FROM TRABNECECOMP
            WHERE NRORG = :P_NRORG
            AND NRNECECOMP = :P_NRNECECOMP
            AND CDFILNECECMP = :P_CDFILNECECMP
            AND CDPRODNECCMP = :P_CDPRODNECCMP
            AND QTPRACOMPRAR > 0
            AND DTENTRNECCMP BETWEEN :P_DTENTRNECCMP AND :P_DTFINAL
            AND IDMARCNECCMP = 'S'
            ORDER BY DTENTRNECCMP";

        $paramsWhere = array(
            'P_NRORG'           => $nrorg,
            'P_NRNECECOMP'   => $nrnececomp,
            'P_CDFILNECECMP' => $cdfilnececmp,
            'P_CDPRODNECCMP' => $cdprodneccmp,
            'P_DTENTRNECCMP' => $dtentrneccmp,
            'P_DTFINAL' => $dtfinal,
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            return $conn->fetchAll($sql, $paramsWhere);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function setIdMarcadoNecessCompras(
        $nrorg, $nrnececomp, $cdfilnececmp, $cdprodneccmp,
        $dtentrneccmp, $id
    ) {
        $sql = "UPDATE TRABNECECOMP
                SET IDMARCNECCMP = :P_ID
                WHERE NRORG      = :P_NRORG
                AND NRNECECOMP   = :P_NRNECECOMP
                AND CDFILNECECMP = :P_CDFILNECECMP
                AND CDPRODNECCMP = :P_CDPRODNECCMP
                AND DTENTRNECCMP = :P_DTENTRNECCMP";

        $paramsWhere = array(
            'P_NRORG'           => $nrorg,
            'P_NRNECECOMP'   => $nrnececomp,
            'P_CDFILNECECMP' => $cdfilnececmp,
            'P_CDPRODNECCMP' => $cdprodneccmp,
            'P_DTENTRNECCMP' => $dtentrneccmp,
            'P_ID' => $id,
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            return $conn->execute($sql, $paramsWhere);
        } catch (\Exception $e) {
            throw $e;
        }
    }
}